@@ -1,7 +1,7 @@
 """The RAAML Modeling Language module is the entrypoint for RAAML related
 assets."""
 
-from typing import Iterable
+from collections.abc import Iterable
 
 from gaphor.abc import ModelingLanguage
 from gaphor.core import gettext
@@ -16,6 +16,7 @@ from gaphor.RAAML.toolbox import (
     raaml_element_types,
     raaml_toolbox_actions,
 )
+from gaphor.UML.treemodel import TreeModel
 
 
 class RAAMLModelingLanguage(ModelingLanguage):
@@ -35,5 +36,10 @@ class RAAMLModelingLanguage(ModelingLanguage):
     def element_types(self) -> Iterable[ElementCreateInfo]:
         yield from raaml_element_types
 
-    def lookup_element(self, name):
+    @property
+    def model_browser_model(self) -> type[TreeModel]:
+        return TreeModel
+
+    def lookup_element(self, name, ns=None):
+        assert ns in ("RAAML", None)
         return getattr(raaml, name, None) or getattr(diagramitems, name, None)
